@@ -223,38 +223,38 @@ void SHA256_Transform(SHA256_CTX*, const sha2_word32*);
 void SHA512_Transform(SHA512_CTX*, const sha2_word64*);
 
 
-/*** SHA-XYZ INITIAL HASH VALUES AND CONSTANTS ************************/
-/* Hash constant words K for SHA-256: */
-const static sha2_word32 K256[64] = {
-	0x428a2f98UL, 0x71374491UL, 0xb5c0fbcfUL, 0xe9b5dba5UL,
-	0x3956c25bUL, 0x59f111f1UL, 0x923f82a4UL, 0xab1c5ed5UL,
-	0xd807aa98UL, 0x12835b01UL, 0x243185beUL, 0x550c7dc3UL,
-	0x72be5d74UL, 0x80deb1feUL, 0x9bdc06a7UL, 0xc19bf174UL,
-	0xe49b69c1UL, 0xefbe4786UL, 0x0fc19dc6UL, 0x240ca1ccUL,
-	0x2de92c6fUL, 0x4a7484aaUL, 0x5cb0a9dcUL, 0x76f988daUL,
-	0x983e5152UL, 0xa831c66dUL, 0xb00327c8UL, 0xbf597fc7UL,
-	0xc6e00bf3UL, 0xd5a79147UL, 0x06ca6351UL, 0x14292967UL,
-	0x27b70a85UL, 0x2e1b2138UL, 0x4d2c6dfcUL, 0x53380d13UL,
-	0x650a7354UL, 0x766a0abbUL, 0x81c2c92eUL, 0x92722c85UL,
-	0xa2bfe8a1UL, 0xa81a664bUL, 0xc24b8b70UL, 0xc76c51a3UL,
-	0xd192e819UL, 0xd6990624UL, 0xf40e3585UL, 0x106aa070UL,
-	0x19a4c116UL, 0x1e376c08UL, 0x2748774cUL, 0x34b0bcb5UL,
-	0x391c0cb3UL, 0x4ed8aa4aUL, 0x5b9cca4fUL, 0x682e6ff3UL,
-	0x748f82eeUL, 0x78a5636fUL, 0x84c87814UL, 0x8cc70208UL,
-	0x90befffaUL, 0xa4506cebUL, 0xbef9a3f7UL, 0xc67178f2UL
-};
+/* /\*** SHA-XYZ INITIAL HASH VALUES AND CONSTANTS ************************\/ */
+/* /\* Hash constant words K for SHA-256: *\/ */
+/* const static sha2_word32 K256[64] = { */
+/* 	0x428a2f98UL, 0x71374491UL, 0xb5c0fbcfUL, 0xe9b5dba5UL, */
+/* 	0x3956c25bUL, 0x59f111f1UL, 0x923f82a4UL, 0xab1c5ed5UL, */
+/* 	0xd807aa98UL, 0x12835b01UL, 0x243185beUL, 0x550c7dc3UL, */
+/* 	0x72be5d74UL, 0x80deb1feUL, 0x9bdc06a7UL, 0xc19bf174UL, */
+/* 	0xe49b69c1UL, 0xefbe4786UL, 0x0fc19dc6UL, 0x240ca1ccUL, */
+/* 	0x2de92c6fUL, 0x4a7484aaUL, 0x5cb0a9dcUL, 0x76f988daUL, */
+/* 	0x983e5152UL, 0xa831c66dUL, 0xb00327c8UL, 0xbf597fc7UL, */
+/* 	0xc6e00bf3UL, 0xd5a79147UL, 0x06ca6351UL, 0x14292967UL, */
+/* 	0x27b70a85UL, 0x2e1b2138UL, 0x4d2c6dfcUL, 0x53380d13UL, */
+/* 	0x650a7354UL, 0x766a0abbUL, 0x81c2c92eUL, 0x92722c85UL, */
+/* 	0xa2bfe8a1UL, 0xa81a664bUL, 0xc24b8b70UL, 0xc76c51a3UL, */
+/* 	0xd192e819UL, 0xd6990624UL, 0xf40e3585UL, 0x106aa070UL, */
+/* 	0x19a4c116UL, 0x1e376c08UL, 0x2748774cUL, 0x34b0bcb5UL, */
+/* 	0x391c0cb3UL, 0x4ed8aa4aUL, 0x5b9cca4fUL, 0x682e6ff3UL, */
+/* 	0x748f82eeUL, 0x78a5636fUL, 0x84c87814UL, 0x8cc70208UL, */
+/* 	0x90befffaUL, 0xa4506cebUL, 0xbef9a3f7UL, 0xc67178f2UL */
+/* }; */
 
-/* Initial hash value H for SHA-256: */
-const static sha2_word32 sha256_initial_hash_value[8] = {
-	0x6a09e667UL,
-	0xbb67ae85UL,
-	0x3c6ef372UL,
-	0xa54ff53aUL,
-	0x510e527fUL,
-	0x9b05688cUL,
-	0x1f83d9abUL,
-	0x5be0cd19UL
-};
+/* /\* Initial hash value H for SHA-256: *\/ */
+/* const static sha2_word32 sha256_initial_hash_value[8] = { */
+/* 	0x6a09e667UL, */
+/* 	0xbb67ae85UL, */
+/* 	0x3c6ef372UL, */
+/* 	0xa54ff53aUL, */
+/* 	0x510e527fUL, */
+/* 	0x9b05688cUL, */
+/* 	0x1f83d9abUL, */
+/* 	0x5be0cd19UL */
+/* }; */
 
 /* Hash constant words K for SHA-384 and SHA-512: */
 const static sha2_word64 K512[80] = {
@@ -300,17 +300,17 @@ const static sha2_word64 K512[80] = {
 	0x5fcb6fab3ad6faecULL, 0x6c44198c4a475817ULL
 };
 
-/* Initial hash value H for SHA-384 */
-const static sha2_word64 sha384_initial_hash_value[8] = {
-	0xcbbb9d5dc1059ed8ULL,
-	0x629a292a367cd507ULL,
-	0x9159015a3070dd17ULL,
-	0x152fecd8f70e5939ULL,
-	0x67332667ffc00b31ULL,
-	0x8eb44a8768581511ULL,
-	0xdb0c2e0d64f98fa7ULL,
-	0x47b5481dbefa4fa4ULL
-};
+/* /\* Initial hash value H for SHA-384 *\/ */
+/* const static sha2_word64 sha384_initial_hash_value[8] = { */
+/* 	0xcbbb9d5dc1059ed8ULL, */
+/* 	0x629a292a367cd507ULL, */
+/* 	0x9159015a3070dd17ULL, */
+/* 	0x152fecd8f70e5939ULL, */
+/* 	0x67332667ffc00b31ULL, */
+/* 	0x8eb44a8768581511ULL, */
+/* 	0xdb0c2e0d64f98fa7ULL, */
+/* 	0x47b5481dbefa4fa4ULL */
+/* }; */
 
 /* Initial hash value H for SHA-512 */
 const static sha2_word64 sha512_initial_hash_value[8] = {
@@ -332,14 +332,16 @@ static const char *sha2_hex_digits = "0123456789abcdef";
 
 
 /*** SHA-256: *********************************************************/
-void SHA256_Init(SHA256_CTX* context) {
+void SHA256_Init(SHA256_CTX* context) { /* #nocov start */ 
+#if 0  
 	if (context == (SHA256_CTX*)0) {
 		return;
 	}
 	MEMCPY_BCOPY(context->state, sha256_initial_hash_value, SHA256_DIGEST_LENGTH);
 	MEMSET_BZERO(context->buffer, SHA256_BLOCK_LENGTH);
 	context->bitcount = 0;
-}
+#endif        
+} /* #nocov end */
 
 #ifdef SHA2_UNROLL_TRANSFORM
 
@@ -436,7 +438,8 @@ void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
 
 #else /* SHA2_UNROLL_TRANSFORM */
 
-void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
+void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) { // #nocov
+#if 0  
 	sha2_word32	a, b, c, d, e, f, g, h, s0, s1;
 	sha2_word32	T1, T2, *W256;
 	int		j;
@@ -512,11 +515,13 @@ void SHA256_Transform(SHA256_CTX* context, const sha2_word32* data) {
 
 	/* Clean up */
 	a = b = c = d = e = f = g = h = T1 = T2 = 0;
-}
+#endif
+}										// #nocov
 
 #endif /* SHA2_UNROLL_TRANSFORM */
 
-void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
+void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {	// #nocov
+#if 0  
 	unsigned int	freespace, usedspace;
 
 	if (len == 0) {
@@ -562,9 +567,11 @@ void SHA256_Update(SHA256_CTX* context, const sha2_byte *data, size_t len) {
 	}
 	/* Clean up: */
 	usedspace = freespace = 0;
-}
+#endif
+}										// #nocov
 
-void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
+void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {			// #nocov
+#if 0  
 	sha2_word32	*d = (sha2_word32*)digest;
 	unsigned int	usedspace;
 
@@ -626,9 +633,10 @@ void SHA256_Final(sha2_byte digest[], SHA256_CTX* context) {
 	/* Clean up state data: */
 	MEMSET_BZERO(context, sizeof(SHA256_CTX));
 	usedspace = 0;
-}
+#endif
+}									// #nocov
 
-char *SHA256_End(SHA256_CTX* context, char buffer[]) {
+char *SHA256_End(SHA256_CTX* context, char buffer[]) { /* #nocov start */ 
 	sha2_byte	digest[SHA256_DIGEST_LENGTH], *d = digest;
 	int		i;
 
@@ -649,21 +657,21 @@ char *SHA256_End(SHA256_CTX* context, char buffer[]) {
 	}
 	MEMSET_BZERO(digest, SHA256_DIGEST_LENGTH);
 	return buffer;
-}
+} 
 
-char* SHA256_Data(const sha2_byte* data, size_t len, char digest[SHA256_DIGEST_STRING_LENGTH]) {
+char* SHA256_Data(const sha2_byte* data, size_t len, char digest[SHA256_DIGEST_STRING_LENGTH]) { 
 	SHA256_CTX	context;
 
 	SHA256_Init(&context);
 	SHA256_Update(&context, data, len);
 	return SHA256_End(&context, digest);
-}
+} /* #nocov end */
 
 
 /*** SHA-512: *********************************************************/
 void SHA512_Init(SHA512_CTX* context) {
 	if (context == (SHA512_CTX*)0) {
-		return;
+		return;								// #nocov
 	}
 	MEMCPY_BCOPY(context->state, sha512_initial_hash_value, SHA512_DIGEST_LENGTH);
 	MEMSET_BZERO(context->buffer, SHA512_BLOCK_LENGTH);
@@ -851,7 +859,7 @@ void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
 	assert(context != (SHA512_CTX*)0 && data != (sha2_byte*)0);
 
 	usedspace = (context->bitcount[0] >> 3) % SHA512_BLOCK_LENGTH;
-	if (usedspace > 0) {
+	if (usedspace > 0) { /* #nocov start */ 
 		/* Calculate how much free space is available in the buffer */
 		freespace = SHA512_BLOCK_LENGTH - usedspace;
 
@@ -870,7 +878,7 @@ void SHA512_Update(SHA512_CTX* context, const sha2_byte *data, size_t len) {
 			usedspace = freespace = 0;
 			return;
 		}
-	}
+	} /* #nocov end */
 	while (len >= SHA512_BLOCK_LENGTH) {
 		/* Process as many complete blocks as we can */
 		SHA512_Transform(context, (sha2_word64*)data);
@@ -903,7 +911,7 @@ void SHA512_Last(SHA512_CTX* context) {
 		if (usedspace <= SHA512_SHORT_BLOCK_LENGTH) {
 			/* Set-up for the last transform: */
 			MEMSET_BZERO(&context->buffer[usedspace], SHA512_SHORT_BLOCK_LENGTH - usedspace);
-		} else {
+		} else { /* #nocov start */ 
 			if (usedspace < SHA512_BLOCK_LENGTH) {
 				MEMSET_BZERO(&context->buffer[usedspace], SHA512_BLOCK_LENGTH - usedspace);
 			}
@@ -912,7 +920,7 @@ void SHA512_Last(SHA512_CTX* context) {
 
 			/* And set-up for the last transform: */
 			MEMSET_BZERO(context->buffer, SHA512_BLOCK_LENGTH - 2);
-		}
+		} /* #nocov end */
 	} else {
 		/* Prepare for final transform: */
 		MEMSET_BZERO(context->buffer, SHA512_SHORT_BLOCK_LENGTH);
@@ -959,7 +967,7 @@ void SHA512_Final(sha2_byte digest[], SHA512_CTX* context) {
 	MEMSET_BZERO(context, sizeof(SHA512_CTX));
 }
 
-char *SHA512_End(SHA512_CTX* context, char buffer[]) {
+char *SHA512_End(SHA512_CTX* context, char buffer[]) { /* #nocov start */ 
 	sha2_byte	digest[SHA512_DIGEST_LENGTH], *d = digest;
 	int		i;
 
@@ -993,19 +1001,24 @@ char* SHA512_Data(const sha2_byte* data, size_t len, char digest[SHA512_DIGEST_S
 
 /*** SHA-384: *********************************************************/
 void SHA384_Init(SHA384_CTX* context) {
+#if 0  
 	if (context == (SHA384_CTX*)0) {
 		return;
 	}
 	MEMCPY_BCOPY(context->state, sha384_initial_hash_value, SHA512_DIGEST_LENGTH);
 	MEMSET_BZERO(context->buffer, SHA384_BLOCK_LENGTH);
 	context->bitcount[0] = context->bitcount[1] = 0;
+#endif
 }
 
 void SHA384_Update(SHA384_CTX* context, const sha2_byte* data, size_t len) {
+#if 0  
 	SHA512_Update((SHA512_CTX*)context, data, len);
+#endif
 }
 
 void SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
+#if 0  
 	sha2_word64	*d = (sha2_word64*)digest;
 
 	/* Sanity check: */
@@ -1032,6 +1045,7 @@ void SHA384_Final(sha2_byte digest[], SHA384_CTX* context) {
 
 	/* Zero out state data */
 	MEMSET_BZERO(context, sizeof(SHA384_CTX));
+#endif
 }
 
 char *SHA384_End(SHA384_CTX* context, char buffer[]) {
@@ -1063,5 +1077,5 @@ char* SHA384_Data(const sha2_byte* data, size_t len, char digest[SHA384_DIGEST_S
 	SHA384_Init(&context);
 	SHA384_Update(&context, data, len);
 	return SHA384_End(&context, digest);
-}
+} /* #nocov end */
 
